@@ -372,12 +372,10 @@ couchdb_document_contact_set_email_addresses (CouchDBDocument *document, GSList
 			json_object_set_object_member (addresses_json,
 						       couchdb_struct_field_get_uuid (sf),
 						       this_address);
-			/* FIXME: crashes if we _unref json_object_unref (this_address); */
 		}
 	}
 
 	json_object_set_object_member (json_node_get_object (document->root_node), "email_addresses", addresses_json);
-	/* FIXME: crashes if we _unref json_object_unref (addresses_json); */
 }
 
 GSList *
@@ -427,12 +425,10 @@ couchdb_document_contact_set_phone_numbers (CouchDBDocument *document, GSList *l
 			json_object_set_object_member (phone_numbers,
 						       couchdb_struct_field_get_uuid (sf),
 						       this_phone);
-			/* FIXME: crashes if we _unref json_object_unref (this_phone); */
 		}
 	}
 
 	json_object_set_object_member (json_node_get_object (document->root_node), "phone_numbers", phone_numbers);
-	/* FIXME: crashes if we _unref json_object_unref (phone_numbers); */
 }
 
 GSList *
@@ -490,12 +486,63 @@ couchdb_document_contact_set_addresses (CouchDBDocument *document, GSList *list)
 			json_object_set_object_member (addresses,
 						       couchdb_struct_field_get_uuid (sf),
 						       this_address);
-			/* FIXME: crashes if we _unref json_object_unref (this_address); */
 		}
 	}
 
 	json_object_set_object_member (json_node_get_object (document->root_node), "addresses", addresses);
-	/* FIXME: crashes if we _unref json_object_unref (addresses); */
+}
+
+GSList *
+couchdb_document_contact_get_im_addresses (CouchDBDocument *document)
+{
+	GSList *list = NULL;
+	JsonObject *im_addresses;
+
+	g_return_val_if_fail (COUCHDB_IS_DOCUMENT (document), NULL);
+	g_return_val_if_fail (couchdb_document_is_contact (document), NULL);
+
+	im_addresses = json_object_get_object_member (
+		json_node_get_object (document->root_node), "im_addresses");
+	if (im_addresses != NULL) {
+		json_object_foreach_member (im_addresses,
+					    (JsonObjectForeach) foreach_object_cb,
+					    &list);
+	}
+
+	return list;
+}
+
+void
+couchdb_document_contact_set_im_addresses (CouchDBDocument *document, GSList *list)
+{
+	GSList *l;
+	JsonObject *im_addresses_json;
+
+	g_return_if_fail (COUCHDB_IS_DOCUMENT (document));
+
+	im_addresses_json = json_object_new ();
+	for (l = list; l != NULL; l = l->next) {
+		const gchar *address_str;
+		CouchDBStructField *sf = (CouchDBStructField *) l->data;
+
+		address_str = couchdb_document_contact_im_get_address (sf);
+		if (address_str != NULL) {
+			JsonObject *this_address;
+
+			this_address = json_object_new ();
+			json_object_set_string_member (this_address, "address", address_str);
+			json_object_set_string_member (this_address, "description",
+						       couchdb_document_contact_im_get_description (sf));
+			json_object_set_string_member (this_address, "protocol",
+						       couchdb_document_contact_im_get_protocol (sf));
+
+			json_object_set_object_member (im_addresses_json,
+						       couchdb_struct_field_get_uuid (sf),
+						       this_address);
+		}
+	}
+
+	json_object_set_object_member (json_node_get_object (document->root_node), "im_addresses", im_addresses_json);
 }
 
 GSList *
@@ -543,12 +590,10 @@ couchdb_document_contact_set_urls (CouchDBDocument *document, GSList *list)
 			json_object_set_object_member (urls_json,
 						       couchdb_struct_field_get_uuid (sf),
 						       this_url);
-			/* FIXME: crashes if we _unref json_object_unref (this_url); */
 		}
 	}
 
 	json_object_set_object_member (json_node_get_object (document->root_node), "urls", urls_json);
-	/* FIXME: crashes if we _unref json_object_unref (urls_json); */
 }
 
 const char *
@@ -848,6 +893,84 @@ couchdb_document_contact_address_set_description (CouchDBStructField *sf, const
 	couchdb_struct_field_set_string_field (sf, "description", description);
 }
 
+CouchDBStructField *
+couchdb_document_contact_im_new (const char *uuid,
+				 const char *address,
+				 const char *description,
+				 const char *protocol)
+{
+	CouchDBStructField *sf;
+
+	sf = couchdb_struct_field_new_from_json_object (json_object_new ());
+	if (uuid != NULL)
+		couchdb_struct_field_set_uuid (sf, uuid);
+	else {
+		char *new_uuid = generate_uuid ();
+		couchdb_struct_field_set_uuid (sf, new_uuid);
+		g_free (new_uuid);
+	}
+
+	if (address != NULL)
+		couchdb_document_contact_im_set_address (sf, address);
+	if (description != NULL)
+		couchdb_document_contact_im_set_description (sf, description);
+	if (protocol != NULL)
+		couchdb_document_contact_im_set_protocol (sf, protocol);
+
+	return sf;
+}
+
+const char *
+couchdb_document_contact_im_get_address (CouchDBStructField *sf)
+{
+	g_return_val_if_fail (sf != NULL, NULL);
+
+	return couchdb_struct_field_get_string_field (sf, "address");
+}
+
+void
+couchdb_document_contact_im_set_address (CouchDBStructField *sf, const char *address)
+{
+	g_return_if_fail (sf != NULL);
+	g_return_if_fail (address != NULL);
+
+	couchdb_struct_field_set_string_field (sf, "address", address);
+}
+
+const char *
+couchdb_document_contact_im_get_description (CouchDBStructField *sf)
+{
+	g_return_val_if_fail (sf != NULL, NULL);
+
+	return couchdb_struct_field_get_string_field (sf, "description");
+}
+
+void
+couchdb_document_contact_im_set_description (CouchDBStructField *sf, const char *description)
+{
+	g_return_if_fail (sf != NULL);
+	g_return_if_fail (description != NULL);
+
+	couchdb_struct_field_set_string_field (sf, "description", description);
+}
+
+const char *
+couchdb_document_contact_im_get_protocol (CouchDBStructField *sf)
+{
+	g_return_val_if_fail (sf != NULL, NULL);
+
+	return couchdb_struct_field_get_string_field (sf, "protocol");
+}
+
+void
+couchdb_document_contact_im_set_protocol (CouchDBStructField *sf, const char *protocol)
+{
+	g_return_if_fail (sf != NULL);
+	g_return_if_fail (protocol != NULL);
+
+	couchdb_struct_field_set_string_field (sf, "protocol", protocol);
+}
+
 CouchDBStructField *
 couchdb_document_contact_url_new (const char *uuid, const char *address, const char *description)
 {
