@@ -70,6 +70,9 @@ void        couchdb_document_contact_set_phone_numbers (CouchDBDocument *documen
 GSList     *couchdb_document_contact_get_addresses (CouchDBDocument *document);
 void        couchdb_document_contact_set_addresses (CouchDBDocument *document, GSList *list);
 
+GSList     *couchdb_document_contact_get_im_addresses (CouchDBDocument *document);
+void        couchdb_document_contact_set_im_addresses (CouchDBDocument *document, GSList *list);
+
 GSList     *couchdb_document_contact_get_urls (CouchDBDocument *document);
 void        couchdb_document_contact_set_urls (CouchDBDocument *document, GSList *list);
 
@@ -83,6 +86,11 @@ void        couchdb_document_contact_set_notes (CouchDBDocument *document, const
 CouchDBStructField *couchdb_document_contact_email_new (const char *uuid, const char *address, const char *description);
 const char         *couchdb_document_contact_email_get_address (CouchDBStructField *sf);
 void                couchdb_document_contact_email_set_address (CouchDBStructField *sf, const char *email);
+
+#define COUCHDB_DOCUMENT_CONTACT_EMAIL_DESCRIPTION_HOME  "home"
+#define COUCHDB_DOCUMENT_CONTACT_EMAIL_DESCRIPTION_OTHER "other"
+#define COUCHDB_DOCUMENT_CONTACT_EMAIL_DESCRIPTION_WORK  "work"
+
 const char         *couchdb_document_contact_email_get_description (CouchDBStructField *sf);
 void                couchdb_document_contact_email_set_description (CouchDBStructField *sf, const char *description);
 
@@ -95,6 +103,23 @@ gint                couchdb_document_contact_phone_get_priority (CouchDBStructFi
 void                couchdb_document_contact_phone_set_priority (CouchDBStructField *sf, gint priority);
 const char         *couchdb_document_contact_phone_get_number (CouchDBStructField *sf);
 void                couchdb_document_contact_phone_set_number (CouchDBStructField *sf, const char *number);
+
+#define COUCHDB_DOCUMENT_CONTACT_PHONE_DESCRIPTION_ASSISTANT "assistant"
+#define COUCHDB_DOCUMENT_CONTACT_PHONE_DESCRIPTION_CALLBACK  "callback"
+#define COUCHDB_DOCUMENT_CONTACT_PHONE_DESCRIPTION_CAR       "car"
+#define COUCHDB_DOCUMENT_CONTACT_PHONE_DESCRIPTION_COMPANY   "company"
+#define COUCHDB_DOCUMENT_CONTACT_PHONE_DESCRIPTION_HOME      "home"
+#define COUCHDB_DOCUMENT_CONTACT_PHONE_DESCRIPTION_HOME_FAX  "home fax"
+#define COUCHDB_DOCUMENT_CONTACT_PHONE_DESCRIPTION_MOBILE    "mobile"
+#define COUCHDB_DOCUMENT_CONTACT_PHONE_DESCRIPTION_OTHER     "other"
+#define COUCHDB_DOCUMENT_CONTACT_PHONE_DESCRIPTION_OTHER_FAX "other fax"
+#define COUCHDB_DOCUMENT_CONTACT_PHONE_DESCRIPTION_PAGER     "pager"
+#define COUCHDB_DOCUMENT_CONTACT_PHONE_DESCRIPTION_PRIMARY   "primary"
+#define COUCHDB_DOCUMENT_CONTACT_PHONE_DESCRIPTION_RADIO     "radio"
+#define COUCHDB_DOCUMENT_CONTACT_PHONE_DESCRIPTION_TELEX     "telex"
+#define COUCHDB_DOCUMENT_CONTACT_PHONE_DESCRIPTION_WORK      "work"
+#define COUCHDB_DOCUMENT_CONTACT_PHONE_DESCRIPTION_WORK_FAX  "work fax"
+
 const char         *couchdb_document_contact_phone_get_description (CouchDBStructField *sf);
 void                couchdb_document_contact_phone_set_description (CouchDBStructField *sf, const char *description);
 
@@ -121,15 +146,49 @@ const char         *couchdb_document_contact_address_get_postalcode (CouchDBStru
 void                couchdb_document_contact_address_set_postalcode (CouchDBStructField *sf, const char *postalcode);
 const char         *couchdb_document_contact_address_get_pobox (CouchDBStructField *sf);
 void                couchdb_document_contact_address_set_pobox (CouchDBStructField *sf, const char *pobox);
+
+#define COUCHDB_DOCUMENT_CONTACT_ADDRESS_DESCRIPTION_HOME  "home"
+#define COUCHDB_DOCUMENT_CONTACT_ADDRESS_DESCRIPTION_OTHER "other"
+#define COUCHDB_DOCUMENT_CONTACT_ADDRESS_DESCRIPTION_WORK  "work"
+
 const char         *couchdb_document_contact_address_get_description (CouchDBStructField *sf);
 void                couchdb_document_contact_address_set_description (CouchDBStructField *sf, const char *description);
 
+/*
+ * Utility functions to manipulate IM addresses
+ */
+CouchDBStructField *couchdb_document_contact_im_new (const char *uuid,
+						     const char *address,
+						     const char *description,
+						     const char *protocol);
+const char         *couchdb_document_contact_im_get_address (CouchDBStructField *sf);
+void                couchdb_document_contact_im_set_address (CouchDBStructField *sf, const char *address);
+const char         *couchdb_document_contact_im_get_description (CouchDBStructField *sf);
+void                couchdb_document_contact_im_set_description (CouchDBStructField *sf, const char *description);
+
+#define COUCHDB_DOCUMENT_CONTACT_IM_PROTOCOL_AIM       "aim"
+#define COUCHDB_DOCUMENT_CONTACT_IM_PROTOCOL_GADU_GADU "gadu-gadu"
+#define COUCHDB_DOCUMENT_CONTACT_IM_PROTOCOL_GROUPWISE "groupwise"
+#define COUCHDB_DOCUMENT_CONTACT_IM_PROTOCOL_ICQ       "icq"
+#define COUCHDB_DOCUMENT_CONTACT_IM_PROTOCOL_IRC       "irc"
+#define COUCHDB_DOCUMENT_CONTACT_IM_PROTOCOL_JABBER    "jabber"
+#define COUCHDB_DOCUMENT_CONTACT_IM_PROTOCOL_MSN       "msn"
+#define COUCHDB_DOCUMENT_CONTACT_IM_PROTOCOL_SKYPE     "skype"
+#define COUCHDB_DOCUMENT_CONTACT_IM_PROTOCOL_YAHOO     "yahoo"
+
+const char         *couchdb_document_contact_im_get_protocol (CouchDBStructField *sf);
+void                couchdb_document_contact_im_set_protocol (CouchDBStructField *sf, const char *protocol);
+
 /*
  * Utility functions to manipulate URLs
  */
 CouchDBStructField *couchdb_document_contact_url_new (const char *uuid, const char *address, const char *description);
 const char         *couchdb_document_contact_url_get_address  (CouchDBStructField *sf);
 void                couchdb_document_contact_url_set_address (CouchDBStructField *sf, const char *address);
+
+#define COUCHDB_DOCUMENT_CONTACT_URL_DESCRIPTION_BLOG     "blog"
+#define COUCHDB_DOCUMENT_CONTACT_URL_DESCRIPTION_HOMEPAGE "home page"
+
 const char         *couchdb_document_contact_url_get_description (CouchDBStructField *sf);
 void                couchdb_document_contact_url_set_description (CouchDBStructField *sf, const char *description);
 #endif
