@@ -63,6 +63,7 @@ typedef struct _CouchDBStructField CouchDBStructField;
 
 GType               couchdb_struct_field_get_type (void);
 CouchDBStructField *couchdb_struct_field_new (void);
+CouchDBStructField *couchdb_struct_field_new_from_string (const char *str);
 CouchDBStructField *couchdb_struct_field_ref (CouchDBStructField *sf);
 void                couchdb_struct_field_unref (CouchDBStructField *sf);
 
@@ -83,4 +84,6 @@ void                couchdb_struct_field_set_struct_field (CouchDBStructField *s
 const char         *couchdb_struct_field_get_uuid (CouchDBStructField *sf);
 void                couchdb_struct_field_set_uuid (CouchDBStructField *sf, const char *uuid);
 
+char               *couchdb_struct_field_to_string (CouchDBStructField *sf);
+
 #endif
